macula_peering_sup (macula v3.13.0)
View SourceTop supervisor for macula_peering.
Hosts the dynamic conn supervisor under which one macula_peering_conn gen_statem is spawned per peer connection.
Top supervisor for macula_peering.
Hosts the dynamic conn supervisor under which one macula_peering_conn gen_statem is spawned per peer connection.