macula_quic_stream_acceptor (macula v0.20.5)

QUIC stream acceptor process. Dedicated process that waits for incoming streams on a connection and forwards them to the gateway for processing.

Summary

Functions

handle_call(Request, From, State)

handle_cast(Msg, State)

handle_info(Info, State)

Handle new stream from peer - THIS IS THE KEY MESSAGE!

init(_)

start_link(GatewayPid, Conn)

-spec start_link(pid(), term()) -> {ok, pid()} | {error, term()}.

Start stream acceptor process

terminate(Reason, State)