macula_stream_acceptor (macula v0.20.5)

Dedicated process for accepting QUIC streams on a connection.

This process runs a blocking loop calling quicer:accept_stream/3, ensuring we're ready to accept streams before the client creates them.

Summary

Functions

Initialize the stream acceptor loop.

Start a stream acceptor for a connection. Gateway is the process that should receive stream data events.

Functions

init(Conn, Gateway)

Initialize the stream acceptor loop.

start_link(Conn, Gateway)

Start a stream acceptor for a connection. Gateway is the process that should receive stream data events.