macula_quic_stream_acceptor (macula v0.20.5)
View SourceQUIC stream acceptor process. Dedicated process that waits for incoming streams on a connection and forwards them to the gateway for processing.
QUIC stream acceptor process. Dedicated process that waits for incoming streams on a connection and forwards them to the gateway for processing.