macula_stream_acceptor (macula v0.20.5)
View SourceDedicated process for accepting QUIC streams on a connection.
This process runs a blocking loop calling quicer:accept_stream/3, ensuring we're ready to accept streams before the client creates them.
Summary
Functions
Initialize the stream acceptor loop.
Start a stream acceptor for a connection. Gateway is the process that should receive stream data events.